package at.jku.ssw.psw2.demos.db;

/**
 * Simple class for representing persons with name and sex
 * 
 * @author hp
 *
 */
public class Person {

	private final int id; 
	private final String name;
	private final Sex sex;

	/**
	 * Constructor initializing name and sex of person
	 * 
	 * @param name
	 *            the name of the person
	 * @param sex
	 *            the sex of the person
	 */
	public Person(int id, String name, Sex sex) {
		super();
		this.id = id; 
		this.name = name;
		this.sex = sex;
	}

	
	/**
	 * Gets the unique id of the person as used in the data base 
	 * 
	 * @return the unique id
	 */
	public int getId() {
		return id;
	}


	/**
	 * Gets the name of the person
	 * 
	 * @return the name of the person
	 */
	public String getName() {
		return name;
	}

	/**
	 * Gets the sex of the person
	 * 
	 * @return the sex of the person
	 */
	public Sex getSex() {
		return sex;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((name == null) ? 0 : name.hashCode());
		result = prime * result + ((sex == null) ? 0 : sex.hashCode());
		return result;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Person other = (Person) obj;
		if (name == null) {
			if (other.name != null)
				return false;
		} else if (!name.equals(other.name))
			return false;
		if (sex != other.sex)
			return false;
		return true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "Person [id =" + id + ", name=" + name + ", sex=" + sex + "]";
	}

}
